@@ -31,6 +31,7 @@
 #include "rc.h"
 #include "options.h"
 #include "gtkseemenu.h"
+#include "gtksee.h"
 
 static GtkWidget *thumbnails_item, *small_icons_item, *details_item;
 
@@ -53,7 +54,7 @@ create_menu(GtkMenuBar *menubar, guchar *label, GtkAcceleratorTable *accel)
 		gtk_menu_set_accelerator_table(GTK_MENU(menu), accel);
 #endif
 	}
-	
+
 #ifdef GTK_HAVE_FEATURES_1_1_2
 	menu_item = gtk_tearoff_menu_item_new();
 	gtk_widget_show(menu_item);
@@ -123,10 +124,10 @@ get_main_menu(GtkWidget *window)
 
 	menubar = gtk_menu_bar_new();
 	gtk_widget_show(menubar);
-	
+
 	/* File menu */
 	menu = create_menu(GTK_MENU_BAR(menubar), _("File"), accel);
-	
+
 	create_menu_item(GTK_MENU(menu), _("View"),
 		GTK_SIGNAL_FUNC(menu_file_view),
 		accel,
@@ -136,7 +137,7 @@ get_main_menu(GtkWidget *window)
 		'V',
 #endif
 		0);
-	
+
 	create_menu_item(GTK_MENU(menu), _("Full-view"),
 		GTK_SIGNAL_FUNC(menu_file_full_view),
 		accel,
@@ -152,7 +153,7 @@ get_main_menu(GtkWidget *window)
 	create_menu_item(GTK_MENU(menu), _("Quit"),
 		GTK_SIGNAL_FUNC(menu_file_quit),
 		accel, GDK_X, GDK_MOD1_MASK);
-	
+
 	/* Edit menu */
 	menu = create_menu(GTK_MENU_BAR(menubar), _("Edit"), accel);
 
@@ -191,7 +192,7 @@ get_main_menu(GtkWidget *window)
 		'8', 0);
 #endif
 	gtk_widget_show(thumbnails_item);
-	
+
 	small_icons_item = gtk_radio_menu_item_new_with_label(group, _("Small icons"));
 	group = gtk_radio_menu_item_group(GTK_RADIO_MENU_ITEM(small_icons_item));
 	gtk_menu_append(GTK_MENU(menu), small_icons_item);
@@ -203,7 +204,7 @@ get_main_menu(GtkWidget *window)
 		'9', 0);
 #endif
 	gtk_widget_show(small_icons_item);
-	
+
 	details_item = gtk_radio_menu_item_new_with_label(group, _("Details"));
 	group = gtk_radio_menu_item_group(GTK_RADIO_MENU_ITEM(details_item));
 	gtk_menu_append(GTK_MENU(menu), details_item);
@@ -215,7 +216,7 @@ get_main_menu(GtkWidget *window)
 		'0', 0);
 #endif
 	gtk_widget_show(details_item);
-	
+
 	menu_set_list_type(rc_get_int("image_list_type"));
 
 	gtk_signal_connect(GTK_OBJECT(thumbnails_item), "toggled",
@@ -241,7 +242,7 @@ get_main_menu(GtkWidget *window)
 		'H', GDK_CONTROL_MASK);
 #endif
 	gtk_widget_show(menu_item);
-	
+
 	menu_item = gtk_check_menu_item_new_with_label(_("Hide non-images"));
 	gtk_check_menu_item_set_state(GTK_CHECK_MENU_ITEM(menu_item),
 		rc_get_boolean("hide_non_images"));
@@ -256,7 +257,7 @@ get_main_menu(GtkWidget *window)
 		'I', GDK_CONTROL_MASK);
 #endif
 	gtk_widget_show(menu_item);
-	
+
 	menu_item = gtk_check_menu_item_new_with_label(_("Fast preview"));
 	gtk_check_menu_item_set_state(GTK_CHECK_MENU_ITEM(menu_item),
 		rc_get_boolean("fast_preview"));
@@ -264,7 +265,7 @@ get_main_menu(GtkWidget *window)
 	gtk_signal_connect(GTK_OBJECT(menu_item), "toggled",
 		GTK_SIGNAL_FUNC(menu_view_preview), NULL);
 	gtk_widget_show(menu_item);
-	
+
 	create_menu_item(GTK_MENU(menu), NULL, NULL, NULL, 0, 0);
 
 	menu_item = create_menu_item(GTK_MENU(menu), _("Sort"), NULL, NULL, 0, 0);
@@ -303,7 +304,7 @@ get_main_menu(GtkWidget *window)
 		'R',
 #endif
 		0);
-	
+
 	create_menu_item(GTK_MENU(menu), _("Quick-refresh"),
 		GTK_SIGNAL_FUNC(menu_view_quick_refresh),
 		accel,
@@ -313,13 +314,13 @@ get_main_menu(GtkWidget *window)
 		'R',
 #endif
 		GDK_SHIFT_MASK);
-	
+
 	menu_item = gtk_check_menu_item_new_with_label(_("Auto-refresh"));
 	gtk_menu_append(GTK_MENU(menu), menu_item);
 	gtk_signal_connect(GTK_OBJECT(menu_item), "toggled",
 		GTK_SIGNAL_FUNC(menu_view_auto_refresh), NULL);
 	gtk_widget_show(menu_item);
-	
+
 	/* Tools menu */
 	menu = create_menu(GTK_MENU_BAR(menubar), _("Tools"), accel);
 
@@ -327,6 +328,10 @@ get_main_menu(GtkWidget *window)
 		GTK_SIGNAL_FUNC(menu_tools_slide_show),
 		accel, GDK_S, GDK_CONTROL_MASK);
 
+	create_menu_item(GTK_MENU(menu), _("The Gimp"),
+		GTK_SIGNAL_FUNC(menu_send_gimp),
+		NULL, 0, 0);
+
 	create_menu_item(GTK_MENU(menu), NULL, NULL, NULL, 0, 0);
 
 	create_menu_item(GTK_MENU(menu), _("Options..."),
@@ -335,29 +340,29 @@ get_main_menu(GtkWidget *window)
 
 	/* Help menu */
 	menu = create_menu(GTK_MENU_BAR(menubar), _("Help"), accel);
-	
+
 	create_menu_item(GTK_MENU(menu), _("Legal"),
 		GTK_SIGNAL_FUNC(menu_help_legal),
 		NULL, 0, 0);
-	
+
 	create_menu_item(GTK_MENU(menu), _("Usage"),
 		GTK_SIGNAL_FUNC(menu_help_usage),
 		NULL, 0, 0);
-	
+
 	create_menu_item(GTK_MENU(menu), _("Known-bugs"),
 		GTK_SIGNAL_FUNC(menu_help_known_bugs),
 		NULL, 0, 0);
-	
+
 	create_menu_item(GTK_MENU(menu), _("Feedback"),
 		GTK_SIGNAL_FUNC(menu_help_feedback),
 		NULL, 0, 0);
-	
+
 	create_menu_item(GTK_MENU(menu), NULL, NULL, NULL, 0, 0);
 
 	create_menu_item(GTK_MENU(menu), _("About"),
 		GTK_SIGNAL_FUNC(menu_help_about),
 		NULL, 0, 0);
-	
+
 	return menubar;
 }
 
@@ -397,7 +402,7 @@ menu_help_legal(GtkWidget *widget, gpointer data)
 		NULL
 	};
 	GtkWidget *dialog;
-	
+
 	dialog = info_dialog_new(_("Legal"), legal_sizes, legal_text);
 	gtk_widget_show(dialog);
 }
@@ -455,7 +460,7 @@ menu_help_usage(GtkWidget *widget, gpointer data)
 		NULL
 	};
 	GtkWidget *dialog;
-	
+
 	dialog = info_dialog_new(_("Usage"), usage_sizes, usage_text);
 	gtk_widget_show(dialog);
 }
@@ -472,7 +477,7 @@ menu_help_known_bugs(GtkWidget *widget, gpointer data)
 		NULL
 	};
 	GtkWidget *dialog;
-	
+
 	dialog = info_dialog_new(_("Known-bugs"), known_bugs_sizes, known_bugs_text);
 	gtk_widget_show(dialog);
 }
@@ -484,15 +489,21 @@ menu_help_feedback(GtkWidget *widget, gpointer data)
 	{
 		FONT_BIG,
 		FONT_SMALL,
-		FONT_SMALL,
 		FONT_BIG,
 		FONT_SMALL,
 		FONT_SMALL,
 		FONT_SMALL,
 		FONT_SMALL,
+		FONT_SMALL,
+		FONT_SMALL,
+		FONT_SMALL,
+		FONT_SMALL,
 		0
 	};
 	static guchar *feedback_text[] = {
+		N_("Comments, suggestions and bug-reportings:\n"),
+		"    Maintainer: keziah@users.berlios.de\n\n",
+		"Original feedback:\n",
 		N_("Comments, suggestions and bug-reportings:\n"),
 		N_("    Please send them to my current primary e-mail address:\n"),
 		"    jkhotaru@mail.sti.com.cn\n\n",
@@ -504,7 +515,21 @@ menu_help_feedback(GtkWidget *widget, gpointer data)
 		NULL
 	};
 	GtkWidget *dialog;
-	
+
 	dialog = info_dialog_new(_("Feedback"), feedback_sizes, feedback_text);
 	gtk_widget_show(dialog);
 }
+
+void menu_send_gimp(GtkWidget *widget, gpointer data)
+{
+  char filen[256];
+  char *cmd;
+
+  if (get_current_image(filen)) {
+    cmd = g_strdup_printf("gimp-remote -n %s &",filen);
+    g_free(cmd);
+    system(cmd);
+  }
+
+  return;
+}
